"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createOrReplaceAllRules = exports.listRules = exports.WebhookIdentityType = void 0;
const transform_error_1 = require("@wix/sdk-runtime/transform-error");
const rename_all_nested_keys_1 = require("@wix/sdk-runtime/rename-all-nested-keys");
const ambassadorWixSocialGroupsV2GroupRules = __importStar(require("./social-groups-v2-group-rules-rules.http.js"));
var WebhookIdentityType;
(function (WebhookIdentityType) {
    WebhookIdentityType["UNKNOWN"] = "UNKNOWN";
    WebhookIdentityType["ANONYMOUS_VISITOR"] = "ANONYMOUS_VISITOR";
    WebhookIdentityType["MEMBER"] = "MEMBER";
    WebhookIdentityType["WIX_USER"] = "WIX_USER";
    WebhookIdentityType["APP"] = "APP";
})(WebhookIdentityType || (exports.WebhookIdentityType = WebhookIdentityType = {}));
/**
 * Retrieves a group's rules.
 *
 * >**Note:**
 * >This endpoint requires [visitor or member authentication](https://dev.wix.com/docs/rest/articles/getting-started/access-types-and-permissions).
 * @param groupId - Group ID.
 * @public
 * @requiredField groupId
 * @fqn wix.social.groups.api.v2.GroupRulesService.ListRules
 */
async function listRules(groupId) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({ groupId: groupId });
    const reqOpts = ambassadorWixSocialGroupsV2GroupRules.listRules(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { groupId: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['groupId']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.listRules = listRules;
/**
 * Creates rules if no rules have been set up. Otherwise, replaces all existing rules.
 *
 * > **Notes:**
 * > + Only group admins can create or replace rules.
 * > + This endpoint requires [visitor or member authentication](https://dev.wix.com/docs/rest/articles/getting-started/access-types-and-permissions).
 * @param groupId - Group ID.
 * @public
 * @requiredField groupId
 * @fqn wix.social.groups.api.v2.GroupRulesService.CreateOrReplaceAllRules
 */
async function createOrReplaceAllRules(groupId, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        groupId: groupId,
        rules: options?.rules,
    });
    const reqOpts = ambassadorWixSocialGroupsV2GroupRules.createOrReplaceAllRules(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { groupId: '$[0]', rules: '$[1].rules' },
            singleArgumentUnchanged: false,
        }, ['groupId', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.createOrReplaceAllRules = createOrReplaceAllRules;
//# sourceMappingURL=social-groups-v2-group-rules-rules.universal.js.map