import { transformError as sdkTransformError } from '@wix/sdk-runtime/transform-error';
import { renameKeysFromSDKRequestToRESTRequest, renameKeysFromRESTResponseToSDKResponse, } from '@wix/sdk-runtime/rename-all-nested-keys';
import * as ambassadorWixSocialGroupsV2GroupRules from './social-groups-v2-group-rules-rules.http.js';
export var WebhookIdentityType;
(function (WebhookIdentityType) {
    WebhookIdentityType["UNKNOWN"] = "UNKNOWN";
    WebhookIdentityType["ANONYMOUS_VISITOR"] = "ANONYMOUS_VISITOR";
    WebhookIdentityType["MEMBER"] = "MEMBER";
    WebhookIdentityType["WIX_USER"] = "WIX_USER";
    WebhookIdentityType["APP"] = "APP";
})(WebhookIdentityType || (WebhookIdentityType = {}));
/**
 * Retrieves a group's rules.
 *
 * >**Note:**
 * >This endpoint requires [visitor or member authentication](https://dev.wix.com/docs/rest/articles/getting-started/access-types-and-permissions).
 * @param groupId - Group ID.
 * @public
 * @requiredField groupId
 * @fqn wix.social.groups.api.v2.GroupRulesService.ListRules
 */
export async function listRules(groupId) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = renameKeysFromSDKRequestToRESTRequest({ groupId: groupId });
    const reqOpts = ambassadorWixSocialGroupsV2GroupRules.listRules(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { groupId: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['groupId']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Creates rules if no rules have been set up. Otherwise, replaces all existing rules.
 *
 * > **Notes:**
 * > + Only group admins can create or replace rules.
 * > + This endpoint requires [visitor or member authentication](https://dev.wix.com/docs/rest/articles/getting-started/access-types-and-permissions).
 * @param groupId - Group ID.
 * @public
 * @requiredField groupId
 * @fqn wix.social.groups.api.v2.GroupRulesService.CreateOrReplaceAllRules
 */
export async function createOrReplaceAllRules(groupId, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        groupId: groupId,
        rules: options?.rules,
    });
    const reqOpts = ambassadorWixSocialGroupsV2GroupRules.createOrReplaceAllRules(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { groupId: '$[0]', rules: '$[1].rules' },
            singleArgumentUnchanged: false,
        }, ['groupId', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
//# sourceMappingURL=social-groups-v2-group-rules-rules.universal.js.map